@@ -14,7 +14,7 @@ import os
 from efficientnet_pytorch import EfficientNet
 import importlib
 import timm
-from tqdm import tqdm
+from tqdm import tqdm_notebook as tqdm
 
 
 availableModels=['ResNet18','ResNet50','ResNet101','EfficientNet','FBNet','MixNet','MNasNet','MobileNet','SqueezeNet','ShuffleNet']
